@@ -1,10 +1,4 @@
 import glob
-YohOB=True
-YohOu=dict
-YohOV=open
-YohOG=False
-YohOC=Exception
-YohOX=int
 import json
 import logging
 import os
@@ -12,6 +6,7 @@ import subprocess
 import sys
 import time
 from ftplib import FTP
+from localstack import config
 from localstack import config as localstack_config
 from localstack.services.generic_proxy import GenericProxy
 from localstack.utils.aws import aws_stack
@@ -21,19 +16,20 @@ from pyftpdlib.authorizers import DummyAuthorizer
 from pyftpdlib.handlers import FTPHandler,TLS_FTPHandler
 from pyftpdlib.servers import FTPServer
 from localstack_ext import config as ext_config
+from localstack_ext.services.transfer.models import User
 LOG=logging.getLogger(__name__)
 ROOT_USER=("root","pass123")
 FTP_USER_DEFAULT_PASSWD="12345"
 FTP_USER_PERMISSIONS="elradfmwMT"
-FTP_PASSIVE_PORTS=[ext_config.SERVICE_INSTANCES_PORTS_END-2,ext_config.SERVICE_INSTANCES_PORTS_END-1,ext_config.SERVICE_INSTANCES_PORTS_END]
-USE_SUBPROCESS=YohOB
+FTP_PASSIVE_PORTS=[config.EXTERNAL_SERVICE_PORTS_END-2,config.EXTERNAL_SERVICE_PORTS_END-1,config.EXTERNAL_SERVICE_PORTS_END]
+USE_SUBPROCESS=True
 DIRECTORY_MAPPING={}
 DIRECTORY_MAPPING_FILE="<data_dir>/ftp.user.dir.mapping.json"
 def get_dir_mapping_key(username,server_port):
  return "{}:{}".format(username,server_port)
 def apply_patches():
  extended_proto_cmds=TLS_FTPHandler.proto_cmds.copy()
- extended_proto_cmds.update({"SITE ADDUSER":YohOu(perm="m",auth=YohOB,arg=YohOB,help="Syntax: SITE <SP> ADDUSER USERNAME PASSWORD HOME PRIVS <SP>.")})
+ extended_proto_cmds.update({"SITE ADDUSER":dict(perm="m",auth=True,arg=True,help="Syntax: SITE <SP> ADDUSER USERNAME PASSWORD HOME PRIVS <SP>.")})
  def _on_file_received(self,file_path):
   key=get_dir_mapping_key(self.username,self.server.address[1])
   mapping=get_directory_mapping()
@@ -43,7 +39,7 @@ def apply_patches():
   bucket=configuration["HomeDirectory"]
   user_dir=configuration["UserDirectory"]
   key=file_path.replace("{}/".format(user_dir),"")
-  with YohOV(file_path)as f:
+  with open(file_path)as f:
    s3_client=aws_stack.connect_to_service("s3")
    s3_client.put_object(Bucket=bucket,Key=key,Body=f.read())
    LOG.info("Received file via FTP -- target: s3://{}/{}".format(bucket,key))
@@ -57,19 +53,19 @@ def apply_patches():
  FTPHandler.ftp_SITE_ADDUSER=_site_adduser
  TLS_FTPHandler.on_file_received=_on_file_received
  TLS_FTPHandler.ftp_SITE_ADDUSER=_site_adduser
-def add_ftp_user(user,server_port):
+def add_ftp_user(user:User,server_port:int):
  ftp=FTP()
  ftp.connect(localstack_config.LOCALSTACK_HOSTNAME,port=server_port)
  ftp.login(ROOT_USER[0],ROOT_USER[1])
  user_dir=new_tmp_dir()
- ftp.sendcmd("SITE ADDUSER  {} {} {} {}".format(user.username,FTP_USER_DEFAULT_PASSWD,user_dir,FTP_USER_PERMISSIONS))
+ ftp.sendcmd("SITE ADDUSER  {} {} {} {}".format(user.user_name,FTP_USER_DEFAULT_PASSWD,user_dir,FTP_USER_PERMISSIONS))
  ftp.quit()
- dir_mapping_key=get_dir_mapping_key(user.username,server_port)
+ dir_mapping_key=get_dir_mapping_key(user.user_name,server_port)
  mapping=user.get_directory_configuration()
  mapping.update({"UserDirectory":user_dir})
  set_directory_mapping(dir_mapping_key,mapping)
-def update_ftp_user(user,server_port):
- dir_mapping_key=get_dir_mapping_key(user.username,server_port)
+def update_ftp_user(user:User,server_port:int):
+ dir_mapping_key=get_dir_mapping_key(user.user_name,server_port)
  set_directory_mapping(dir_mapping_key,user.get_directory_configuration())
 def start_ftp(port):
  if USE_SUBPROCESS:
@@ -84,16 +80,16 @@ def start_ftp(port):
    pythonpath+=":%s"%":".join(paths)
   env_vars={"SERVICES":services,"PYTHONPATH":pythonpath}
   cmd="%s %s %s"%(sys.executable,__file__,port)
-  thread=ShellCommandThread(cmd,outfile=subprocess.PIPE,env_vars=env_vars,quiet=YohOG)
+  thread=ShellCommandThread(cmd,outfile=subprocess.PIPE,env_vars=env_vars,quiet=False)
   thread.start()
   time.sleep(2)
  else:
-  thread=do_start_ftp(port,asynchronous=YohOB)
+  thread=do_start_ftp(port,asynchronous=True)
  time.sleep(2)
  wait_for_port_open(port,retries=10,sleep_time=1.5)
  TMP_THREADS.append(thread)
  return thread
-def do_start_ftp(port,asynchronous=YohOB):
+def do_start_ftp(port,asynchronous=True):
  LOG.info("Starting (S)FTP server on port %s..."%port)
  apply_patches()
  authorizer=DummyAuthorizer()
@@ -111,7 +107,7 @@ def do_start_ftp(port,asynchronous=YohOB):
   try:
    server=FTPServer(("0.0.0.0",port),handler)
    server.serve_forever()
-  except YohOC as e:
+  except Exception as e:
    LOG.info("Unable to run FTP server on port %s: %s"%(port,e))
    raise
  if asynchronous:
@@ -133,9 +129,9 @@ def set_directory_mapping(key,value):
   save_file(dir_file,json.dumps(mapping))
  return value
 def get_directory_mapping_file():
- return DIRECTORY_MAPPING_FILE.replace("<data_dir>",localstack_config.TMP_FOLDER)
+ return DIRECTORY_MAPPING_FILE.replace("<data_dir>",localstack_config.dirs.tmp)
 def main():
- do_start_ftp(YohOX(sys.argv[1]),asynchronous=YohOG)
+ do_start_ftp(int(sys.argv[1]),asynchronous=False)
 if __name__=="__main__":
  main()
 # Created by pyminifier (https://github.com/liftoff/pyminifier)
