@@ -1,26 +1,16 @@
 #!/usr/bin/env python
-nUITl=dict
-nUITA=super
-nUITP=hasattr
-nUITN=Exception
-nUITR=object
-nUITe=dir
-nUITS=None
-nUITc=False
-nUITJ=True
-nUITi=len
-nUITa=set
 import errno
 import socket
-from select import select
 from socket import(AF_INET,AF_INET6,IPPROTO_IPV6,IPPROTO_TCP,IPV6_V6ONLY,SO_REUSEADDR,SOCK_STREAM,SOL_SOCKET,TCP_NODELAY)
-class AttrDict(nUITl):
+from localstack.utils.common import start_thread
+from localstack.utils.server.proxy_server import start_tcp_proxy
+class AttrDict(dict):
  def __init__(self,*args,**kwargs):
-  nUITA(AttrDict,self).__init__(*args,**kwargs)
+  super(AttrDict,self).__init__(*args,**kwargs)
   self.__dict__=self
 def tcp_listen(six,addr,port,blk):
  s=socket.socket(AF_INET6 if six else AF_INET,SOCK_STREAM)
- if six and nUITP(socket,"IPV6_V6ONLY"):
+ if six and hasattr(socket,"IPV6_V6ONLY"):
   s.setsockopt(IPPROTO_IPV6,IPV6_V6ONLY,0)
  s.setsockopt(SOL_SOCKET,SO_REUSEADDR,1)
  s.setsockopt(IPPROTO_TCP,TCP_NODELAY,1)
@@ -37,9 +27,9 @@ def tcp_connect(six,addr,port,blk):
 def safe_close(x):
  try:
   x.close()
- except nUITN:
+ except Exception:
   pass
-class Server(nUITR):
+class Server(object):
  def __init__(self,opt,q):
   self.opt=opt
   self.sock=tcp_listen(opt.ip6,opt.bind_addr,opt.bind_port,0)
@@ -51,17 +41,17 @@ class Server(nUITR):
    cl,addr=self.sock.accept()
    cl.setblocking(0)
    self.q.append(Proxy(self.opt,cl,addr))
-class Half(nUITR):
- def __init__(self,opt,sock,addr,nUITe):
+class Half(object):
+ def __init__(self,opt,sock,addr,dir):
   self.opt=opt
   self.sock=sock
   self.addr=addr
-  self.nUITe=nUITe
-  self.name="peer" if self.nUITe else "client"
+  self.dir=dir
+  self.name="peer" if self.dir else "client"
   self.queue=[]
-  self.dest=nUITS
-  self.err=nUITS
-  self.ready=nUITc
+  self.dest=None
+  self.err=None
+  self.ready=False
  def pre_wait(self,rr,r,w,e):
   if self.ready:
    rr.append(self.sock)
@@ -72,7 +62,7 @@ class Half(nUITR):
   if not self.err and self.sock in w and self.queue:
    self.write_some()
   if not self.err and self.sock in r:
-   self.ready=nUITJ
+   self.ready=True
    self.copy()
   return self.err
  def error(self,msg,e):
@@ -81,9 +71,9 @@ class Half(nUITR):
  def write_some(self):
   try:
    n=self.sock.send(self.queue[0])
-  except nUITN as e:
+  except Exception as e:
    return self.error("send error",e)
-  if n!=nUITi(self.queue[0]):
+  if n!=len(self.queue[0]):
    self.queue[0]=self.queue[0][n:]
   else:
    del self.queue[0]
@@ -92,17 +82,17 @@ class Half(nUITR):
    buf=self.sock.recv(4096)
   except socket.error as e:
    if e.errno==errno.EWOULDBLOCK:
-    self.ready=nUITc
+    self.ready=False
     return
    return self.error("recv socket error",e)
-  except nUITN as e:
+  except Exception as e:
    return self.error("recv error",e)
-  if nUITi(buf)==0:
+  if len(buf)==0:
    return self.error("eof",0)
   self.dest.queue.append(buf)
  def close(self):
   safe_close(self.sock)
-class Proxy(nUITR):
+class Proxy(object):
  def __init__(self,opt,sock,addr):
   self.opt=opt
   self.cl=Half(opt,sock,addr,"i")
@@ -110,7 +100,7 @@ class Proxy(nUITR):
   self.peer=Half(opt,peer,addr,"o")
   self.cl.dest=self.peer
   self.peer.dest=self.cl
-  self.err=nUITS
+  self.err=None
  def pre_wait(self,rr,r,w,e):
   self.cl.pre_wait(rr,r,w,e)
   self.peer.pre_wait(rr,r,w,e)
@@ -124,28 +114,19 @@ class Proxy(nUITR):
    self.peer.close()
   return self.err
 def server_loop(opt):
- qs=[]
- opt["ip6"]=opt.get("ip6",nUITc)
+ opt["ip6"]=opt.get("ip6",False)
  opt["bind_addr"]=opt.get("bind_addr","0.0.0.0")
  opt["addr"]=opt.get("addr","127.0.0.1")
  opt["bind_port"]=opt.get("bind_port",0)
- opt=AttrDict(opt)
- qs.append(Server(opt,qs))
- while qs:
-  rr,r,w,e=[],[],[],[]
-  for q in qs:
-   q.pre_wait(rr,r,w,e)
-  timeo=10.0 if not rr else 0.0
-  r,w,e=select(r,w,e,timeo)
-  r=nUITa(r).union(rr)
-  for q in qs:
-   if q.post_wait(r,w,e):
-    qs.remove(q)
+ listen=f"{opt['bind_addr']}:{opt['bind_port']}"
+ target=f"{opt['addr']}:{opt['port']}"
+ proxy=start_thread(lambda*args,**kwargs:start_tcp_proxy(listen,target,handler=None,**kwargs))
+ return proxy.join()
 def main():
- opt={"ip6":nUITc,"bind_port":2223,"addr":"192.168.43.191","port":22}
- opt={"ip6":nUITc,"bind_port":48429,"addr":"128.0.100.3","port":22}
- opt={"ip6":nUITc,"port":54237,"bind_addr":"128.0.100.2","bind_port":22}
- opt={"ip6":nUITc,"port":54237,"bind_addr":"192.168.100.3","bind_port":22}
+ opt={"ip6":False,"bind_port":2223,"addr":"192.168.43.191","port":22}
+ opt={"ip6":False,"bind_port":48429,"addr":"128.0.100.3","port":22}
+ opt={"ip6":False,"port":54237,"bind_addr":"128.0.100.2","bind_port":22}
+ opt={"ip6":False,"port":54237,"bind_addr":"192.168.100.3","bind_port":22}
  server_loop(opt)
 if __name__=="__main__":
  main()
