@@ -34,6 +34,7 @@ DNS_RESOLVE_IP = os.environ.get("DNS_RESOLVE_IP") or LOCALHOST_IP
 
 # fallback DNS server to send upstream requests to
 DNS_SERVER = os.environ.get("DNS_SERVER")
+DNS_VERIFICATION_DOMAIN = os.environ.get("DNS_VERIFICATION_DOMAIN") or "localstack.cloud"
 
 # SMTP settings (required, e.g., for Cognito)
 SMTP_HOST = os.environ.get("SMTP_HOST", "")
@@ -59,14 +60,14 @@ DNS_LOCAL_NAME_PATTERNS = (os.environ.get("DNS_LOCAL_NAME_PATTERNS") or "").stri
 #  AWS SDK clients used in user code (e.g., Lambdas). default: true
 TRANSPARENT_LOCAL_ENDPOINTS = localstack_config.is_env_not_false("TRANSPARENT_LOCAL_ENDPOINTS")
 
-# whether to use static ports and IDs (e.g., cf-<port>) for CloudFormation distributions
-CLOUDFRONT_STATIC_PORTS = localstack_config.is_env_true("CLOUDFRONT_STATIC_PORTS")
-
 # whether to enforce IAM policies when processing requests
 ENFORCE_IAM = localstack_config.is_env_true("ENFORCE_IAM")
 
 # folder with persistent API backend states
-BACKEND_STATES_DIR = os.path.join(localstack_config.DATA_DIR, "api_states")
+BACKEND_STATES_DIR = os.path.join(localstack_config.dirs.data, "api_states")
+
+# whether to enable extended persistence, storing "all" state like Lambda function code, etc
+PERSIST_ALL = localstack_config.is_env_not_false("PERSIST_ALL")
 
 # whether to require Pro features and exit with a fault if the API key cannot be activated
 REQUIRE_PRO = localstack_config.is_env_true("REQUIRE_PRO")
@@ -74,24 +75,36 @@ REQUIRE_PRO = localstack_config.is_env_true("REQUIRE_PRO")
 # endpoint URL for kube cluster (defaults to https://<docker_bridge_ip>:6443)
 KUBE_ENDPOINT = os.environ.get("KUBE_ENDPOINT", "")
 
+# whether flushing persistence state always or at time intervals
+PERSIST_FLUSH_STRATEGY = os.environ.get("PERSIST_FLUSH_STRATEGY", "").strip() or "always"
+
+
+# ---
+# service-specific configurations
+# ---
+
+
+# whether to fully initialize XRay daemon for Lambda (increases Lambda startup times, hence disabled by default)
+LAMBDA_XRAY_INIT = localstack_config.is_env_true("LAMBDA_XRAY_INIT")
+
+# whether to use static ports and IDs (e.g., cf-<port>) for CloudFormation distributions
+CLOUDFRONT_STATIC_PORTS = localstack_config.is_env_true("CLOUDFRONT_STATIC_PORTS")
+
+# whether to start the EC2 daemon on the host (which requires sudo privileges)
+EC2_AUTOSTART_DAEMON = localstack_config.is_env_true("EC2_AUTOSTART_DAEMON")
+
+# EC2 VM manager which is a supported hypervisor or container engine
+EC2_VM_MANAGER = os.environ.get("EC2_VM_MANAGER", "").strip() or "virtualbox"
+
 
 def use_custom_dns():
     return str(DNS_ADDRESS) not in FALSE_STRINGS
 
 
-# set USE_SSL to true by default
-# TODO fix this!
-# localstack_config.USE_SSL = os.environ.get('USE_SSL', '').lower().strip() not in FALSE_STRINGS
-
 # backend service ports
 DEFAULT_PORT_LOCAL_DAEMON = 4600
 DEFAULT_PORT_LOCAL_DAEMON_ROOT = 4601
-
-# port ranges for service instances (e.g., Postgres DBs, ElastiCache clusters, ...)
-SERVICE_INSTANCES_PORTS_START = int(os.environ.get("SERVICE_INSTANCES_PORTS_START") or 4510)
-SERVICE_INSTANCES_PORTS_END = int(
-    os.environ.get("SERVICE_INSTANCES_PORTS_END") or (SERVICE_INSTANCES_PORTS_START + 30)
-)
+DISABLE_LOCAL_DAEMON_CONNECTION = localstack_config.is_env_true("DISABLE_LOCAL_DAEMON_CONNECTION")
 
 # port for Azure APIs
 PORT_AZURE = 12121
@@ -99,12 +112,17 @@ PORT_AZURE = 12121
 # add default service ports (TODO needed?)
 localstack_constants.DEFAULT_SERVICE_PORTS["azure"] = PORT_AZURE
 
-# name of cloud pod to sync state with (e.g., used during CI runs)
-SYNC_POD_NAME = os.environ.get("SYNC_POD_NAME") or ""
-SYNC_POD_VERSION = None
 # name of CI project to sync usage events and state with
 CI_PROJECT = os.environ.get("CI_PROJECT") or ""
 
+# Controls the snapshot granularity of the run. The lower the interval, the more snapshot metamodels are created
+COMMIT_INTERVAL_SECS = os.environ.get("COMMIT_INTERVAL_SECS", 10)
+
+# Controls the synchronization rate of the run. The lower the rate, the more remote synchronization requests are performed.
+#  Note: If the container shuts down gracefully a synchronization request is done at the very end of the run, otherwise
+#   all results up until the last synchronization request are lost.
+SYNCHRONIZATION_RATE = os.environ.get("SYNCHRONIZATION_RATE", 1)
+
 # Docker host name resolvable from containers
 DOCKER_HOST_NAME = "host.docker.internal"
 
@@ -145,13 +163,16 @@ localstack_config.CONFIG_ENV_VARS += [
     "BIGDATA_DOCKER_FLAGS",
     "CI_PROJECT",
     "CLOUDFRONT_STATIC_PORTS",
+    "DISABLE_LOCAL_DAEMON_CONNECTION",
     "DNS_ADDRESS",
     "DNS_LOCAL_NAME_PATTERNS",
     "DNS_RESOLVE_IP",
     "DNS_SERVER",
     "ENFORCE_IAM",
     "KUBE_ENDPOINT",
+    "LAMBDA_XRAY_INIT",
     "LOG_LICENSE_ISSUES",
+    "PERSIST_ALL",
     "REQUIRE_PRO",
     "SMTP_EMAIL",
     "SMTP_HOST",
@@ -159,7 +180,8 @@ localstack_config.CONFIG_ENV_VARS += [
     "SMTP_USER",
     "SYNC_POD_NAME",
     "TRANSPARENT_LOCAL_ENDPOINTS",
+    "PERSIST_FLUSH_STRATEGY",
 ]
 
 # re-initialize configs in localstack
-localstack_config.populate_configs()
+localstack_config.populate_config_env_var_names()
