@@ -10,10 +10,8 @@ TOKEN_EXPIRY_SECONDS = 24 * 60 * 60
 # name of Docker registry for Lambda images
 DEFAULT_LAMBDA_DOCKER_REGISTRY = "localstack/lambda"
 
-# Github repo with various code artifacts
-ARTIFACTS_REPO = "https://github.com/localstack/localstack-artifacts"
-
 # request path for local pod management API
 API_PATH_PODS = "/_pods"
 
-API_STATES_DIR = "api_states"
+# name of S3 bucket containing assets that are lazily downloaded - TODO: unify assets bucket layout/naming
+ASSETS_S3_BUCKET = "localstack-web-assets"
