@@ -20,11 +20,13 @@ __all__ = [  # noqa: F405
     "iotanalytics",
     "kinesisanalytics",
     "msk",
+    "qldb",
     "rds",
     "redshift",
     "route53",
     "servicediscovery",
     "ses",
+    "timestream",
 ]
 
 # leave this star import here, so we can "import ...cloudformation.models" inside patch functions (not module level)
