@@ -1,11 +1,8 @@
 from localstack.utils.aws import aws_stack
-PVQnv=staticmethod
-PVQnX=None
-PVQnx=classmethod
 from localstack.utils.common import select_attributes
 from localstack_ext.services.cloudformation.models.servicediscovery import ServiceDiscoveryNamespace
 class ApplicationAutoScalingPolicy(ServiceDiscoveryNamespace):
- @PVQnv
+ @staticmethod
  def cloudformation_type():
   return "AWS::ApplicationAutoScaling::ScalingPolicy"
  def fetch_state(self,stack_name,resources):
@@ -19,10 +16,10 @@ class ApplicationAutoScalingPolicy(ServiceDiscoveryNamespace):
   service_ns=self.resolve_refs_recursively(stack_name,service_ns,resources)
   policies=client.describe_scaling_policies(ServiceNamespace=service_ns)["ScalingPolicies"]
   policy=[p for p in policies if p["PolicyName"]==pol_name]
-  return(policy or[PVQnX])[0]
+  return(policy or[None])[0]
  def get_physical_resource_id(self,attribute,**kwargs):
   return self.props.get("PolicyARN")
- @PVQnx
+ @classmethod
  def get_deploy_templates(cls):
   def get_scaling_policy_params(params,**kwargs):
    attrs=("PolicyName","ServiceNamespace","ResourceId","ScalableDimension","PolicyType","StepScalingPolicyConfiguration","TargetTrackingScalingPolicyConfiguration")
@@ -36,7 +33,7 @@ class ApplicationAutoScalingPolicy(ServiceDiscoveryNamespace):
    return result
   return{"create":{"function":"put_scaling_policy","parameters":get_scaling_policy_params},"delete":{"function":"delete_scaling_policy","parameters":["PolicyName","ServiceNamespace","ResourceId","ScalableDimension"]}}
 class ApplicationAutoScalingScalableTarget(ServiceDiscoveryNamespace):
- @PVQnv
+ @staticmethod
  def cloudformation_type():
   return "AWS::ApplicationAutoScaling::ScalableTarget"
  def fetch_state(self,stack_name,resources):
@@ -47,13 +44,13 @@ class ApplicationAutoScalingScalableTarget(ServiceDiscoveryNamespace):
   service_ns=self.resolve_refs_recursively(stack_name,props["ServiceNamespace"],resources)
   services=client.describe_scalable_targets(ServiceNamespace=service_ns)["ScalableTargets"]
   service=[s for s in services if s["ResourceId"]==resource_id and s["ScalableDimension"]==scal_dim and s["ServiceNamespace"]==service_ns]
-  return(service or[PVQnX])[0]
+  return(service or[None])[0]
  def get_physical_resource_id(self,attribute,**kwargs):
   if not self.state:
    return
   props=self.props
   return "service/%s|%s|%s"%(props["ResourceId"],props["ScalableDimension"],props["ServiceNamespace"])
- @PVQnx
+ @classmethod
  def get_deploy_templates(cls):
   return{"create":{"function":"register_scalable_target","parameters":["ServiceNamespace","ResourceId","ScalableDimension","MinCapacity","MaxCapacity","RoleARN","SuspendedState"]},"delete":{"function":"deregister_scalable_target","parameters":["ServiceNamespace","ResourceId","ScalableDimension"]}}
 # Created by pyminifier (https://github.com/liftoff/pyminifier)
