@@ -1,11 +1,4 @@
 import json
-kGfRW=staticmethod
-kGfRI=classmethod
-kGfRn=None
-kGfRP=True
-kGfRM=hasattr
-kGfRQ=Exception
-kGfRp=super
 from localstack.services.cloudformation.service_models import(REF_ARN_ATTRS,REF_ID_ATTRS,GenericBaseModel)
 from localstack.utils.aws import aws_stack
 from localstack.utils.common import clone,keys_to_lower,select_attributes,to_str
@@ -13,7 +6,7 @@ from localstack_ext.services.appsync import appsync_api
 from localstack_ext.services.cloudformation.service_models import LOG
 from localstack_ext.utils.aws import aws_utils
 class AppSyncResolver(GenericBaseModel):
- @kGfRW
+ @staticmethod
  def cloudformation_type():
   return "AWS::AppSync::Resolver"
  def get_physical_resource_id(self,attribute,**kwargs):
@@ -26,40 +19,40 @@ class AppSyncResolver(GenericBaseModel):
   field_name=props.get("FieldName")
   data_source_name=props.get("DataSourceName")
   return self.fetch_details(api_id,type_name,field_name,data_source_name)
- @kGfRI
+ @classmethod
  def fetch_details(cls,api_id,type_name,field_name,data_source_name):
   client=aws_stack.connect_to_service("appsync")
   resolvers=client.list_resolvers(apiId=api_id,typeName=type_name)["resolvers"]
   result=[r for r in resolvers if r.get("fieldName")==field_name and r.get("dataSourceName")==data_source_name]
-  return(result or[kGfRn])[0]
- @kGfRW
+  return(result or[None])[0]
+ @staticmethod
  def get_deploy_templates():
   def get_resolver_params(params,**kwargs):
    params=keys_to_lower(clone(params))
-   req_template=params.pop("requestMappingTemplateS3Location",kGfRn)
-   res_template=params.pop("responseMappingTemplateS3Location",kGfRn)
+   req_template=params.pop("requestMappingTemplateS3Location",None)
+   res_template=params.pop("responseMappingTemplateS3Location",None)
    if req_template:
-    tmpl=aws_utils.download_s3_object(req_template,as_str=kGfRP)
+    tmpl=aws_utils.download_s3_object(req_template,as_str=True)
     if tmpl:
      params["requestMappingTemplate"]=tmpl
    if res_template:
-    tmpl=aws_utils.download_s3_object(res_template,as_str=kGfRP)
+    tmpl=aws_utils.download_s3_object(res_template,as_str=True)
     if tmpl:
      params["responseMappingTemplate"]=tmpl
    return params
   return{"create":{"function":"create_resolver","parameters":get_resolver_params}}
 class GraphQLSchema(GenericBaseModel):
- @kGfRW
+ @staticmethod
  def cloudformation_type():
   return "AWS::AppSync::GraphQLSchema"
  def get_physical_resource_id(self,attribute,**kwargs):
   return "%s-GraphQLSchema"%self.props.get("ApiId")
- @kGfRI
- def fetch_details(cls,api_id,definition=kGfRn,s3_location=kGfRn):
+ @classmethod
+ def fetch_details(cls,api_id,definition=None,s3_location=None):
   client=aws_stack.connect_to_service("appsync")
   try:
    schema=client.get_introspection_schema(apiId=api_id,format="SDL")["schema"]
-   schema=schema.read()if kGfRM(schema,"read")else schema
+   schema=schema.read()if hasattr(schema,"read")else schema
    schema=to_str(schema)
    if schema.startswith("{"):
     schema=json.loads(schema)["schema"]
@@ -69,10 +62,10 @@ class GraphQLSchema(GenericBaseModel):
    elif s3_location:
     LOG.debug("Getting GraphQL schema definition from S3 not yet implemented")
     return{"schema":definition}
-  except kGfRQ:
+  except Exception:
    pass
 class AppSyncApiKey(GenericBaseModel):
- @kGfRW
+ @staticmethod
  def cloudformation_type():
   return "AWS::AppSync::ApiKey"
  def get_cfn_attribute(self,attribute_name):
@@ -81,8 +74,8 @@ class AppSyncApiKey(GenericBaseModel):
    return "key-%s"%props["ApiId"]
   if attribute_name in REF_ID_ATTRS+REF_ARN_ATTRS:
    return self.get_physical_resource_id()
-  return kGfRp(AppSyncApiKey,self).get_cfn_attribute(attribute_name)
- def get_physical_resource_id(self,attribute=kGfRn,**kwargs):
+  return super(AppSyncApiKey,self).get_cfn_attribute(attribute_name)
+ def get_physical_resource_id(self,attribute=None,**kwargs):
   props=self.props
   key_id=props.get("ApiKeyId")or props.get("id")
   if not key_id or not props.get("ApiId"):
@@ -94,9 +87,11 @@ class AppSyncApiKey(GenericBaseModel):
   api_id=props.get("ApiId")
   api_id=self.resolve_refs_recursively(stack_name,api_id,resources)
   keys=client.list_api_keys(apiId=api_id).get("apiKeys",[])
-  result=[k for k in keys if k.get("description")==props.get("Description")and props.get("Expires")in[kGfRn,k.get("expires")]]
-  return(result or[kGfRn])[0]
- @kGfRI
+  expires=props.get("expires")or props.get("Expires")
+  description=props.get("Description")
+  result=[k for k in keys if k.get("description")==description and expires in[None,k.get("expires")]]
+  return(result or[None])[0]
+ @classmethod
  def get_deploy_templates(cls):
   def _create_params(_,resources,resource_id,**kwargs):
    resource=cls(resources[resource_id])
@@ -104,14 +99,16 @@ class AppSyncApiKey(GenericBaseModel):
    if not res_props.get("Description"):
     api_id=resource.resolve_refs_recursively(kwargs.get("stack_name"),res_props.get("ApiId"),resources)
     res_props["Description"]=f"Generated API key for AppSync API ID {api_id}"
+   if res_props.get("Expires"):
+    res_props["Expires"]=int(res_props.get("Expires"))
    result=keys_to_lower(select_attributes(res_props,["ApiId","Description","Expires"]))
    return result
   return{"create":{"function":"create_api_key","parameters":_create_params}}
 class AppSyncDataSource(GenericBaseModel):
- @kGfRW
+ @staticmethod
  def cloudformation_type():
   return "AWS::AppSync::DataSource"
- @kGfRW
+ @staticmethod
  def get_deploy_templates():
   def lambda_get_datasource_config(params,**kwargs):
    params=keys_to_lower(clone(params))
@@ -124,8 +121,8 @@ class AppSyncDataSource(GenericBaseModel):
    return self.props.get("dataSourceArn")
   if attribute_name=="Name":
    return self.props.get("name")
-  return kGfRp(AppSyncDataSource,self).get_cfn_attribute(attribute_name)
- def get_physical_resource_id(self,attribute=kGfRn,**kwargs):
+  return super(AppSyncDataSource,self).get_cfn_attribute(attribute_name)
+ def get_physical_resource_id(self,attribute=None,**kwargs):
   return self.props.get("dataSourceArn")
  def fetch_state(self,stack_name,resources):
   props=self.props
@@ -134,9 +131,9 @@ class AppSyncDataSource(GenericBaseModel):
   ds_name=self.resolve_refs_recursively(stack_name,ds_name,resources)
   api_id=self.resolve_refs_recursively(stack_name,props.get("ApiId"),resources)
   sources=client.list_data_sources(apiId=api_id)["dataSources"]
-  return([s for s in sources if s["name"]==ds_name]or[kGfRn])[0]
+  return([s for s in sources if s["name"]==ds_name]or[None])[0]
 class AppSyncFunctionConfig(GenericBaseModel):
- @kGfRW
+ @staticmethod
  def cloudformation_type():
   return "AWS::AppSync::FunctionConfiguration"
  def fetch_state(self,stack_name,resources):
@@ -146,7 +143,7 @@ class AppSyncFunctionConfig(GenericBaseModel):
   name=self.resolve_refs_recursively(stack_name,props["Name"],resources)
   result=client.list_functions(apiId=api_id).get("functions",[])
   result=[f for f in result if f.get("name")==name]
-  return(result or[kGfRn])[0]
+  return(result or[None])[0]
  def get_cfn_attribute(self,attribute_name):
   props=self.props
   if attribute_name=="FunctionId":
@@ -157,10 +154,10 @@ class AppSyncFunctionConfig(GenericBaseModel):
    return props.get("name")
   if attribute_name=="DataSourceName":
    return props.get("dataSourceName")
-  return kGfRp(AppSyncFunctionConfig,self).get_cfn_attribute(attribute_name)
+  return super(AppSyncFunctionConfig,self).get_cfn_attribute(attribute_name)
  def get_physical_resource_id(self,attribute,**kwargs):
   return self.props.get("functionArn")
- @kGfRW
+ @staticmethod
  def get_deploy_templates():
   def func_params(params,**kwargs):
    sys_cfg=params.get("SyncConfig")
@@ -171,7 +168,7 @@ class AppSyncFunctionConfig(GenericBaseModel):
    return result
   return{"create":{"function":"create_function","parameters":func_params}}
 class GraphQLAPI(GenericBaseModel):
- @kGfRW
+ @staticmethod
  def cloudformation_type():
   return "AWS::AppSync::GraphQLApi"
  def get_cfn_attribute(self,attribute_name):
@@ -179,21 +176,21 @@ class GraphQLAPI(GenericBaseModel):
   if not props.get("apiId"):
    details=self.fetch_details(props.get("Name"))
    if not details:
-    raise kGfRQ('Unable to find GraphQL API named "%s"'%props.get("Name"))
+    raise Exception('Unable to find GraphQL API named "%s"'%props.get("Name"))
    props["apiId"]=details["apiId"]
   if attribute_name=="ApiId":
    return props.get("apiId")
   if attribute_name in REF_ARN_ATTRS:
    return self.get_physical_resource_id(attribute_name)
   if attribute_name=="GraphQLUrl":
-   return appsync_api.get_graphql_url(props["apiId"],use_domain_name=kGfRP)
-  return kGfRp(GraphQLAPI,self).get_cfn_attribute(attribute_name)
+   return appsync_api.get_graphql_url(props["apiId"],use_domain_name=True)
+  return super(GraphQLAPI,self).get_cfn_attribute(attribute_name)
  def get_physical_resource_id(self,attribute,**kwargs):
   props=self.props
   return props.get("apiId")and aws_utils.appsync_api_arn(props["apiId"])
- @kGfRI
+ @classmethod
  def fetch_details(cls,api_name):
   client=aws_stack.connect_to_service("appsync")
   apis=client.list_graphql_apis()["graphqlApis"]
-  return([a for a in apis if a["name"]==api_name]or[kGfRn])[0]
+  return([a for a in apis if a["name"]==api_name]or[None])[0]
 # Created by pyminifier (https://github.com/liftoff/pyminifier)
