@@ -1,36 +1,33 @@
+from typing import Tuple
 from localstack.services.cloudformation.deployment_utils import param_json_to_str
-NeEkn=staticmethod
-NeEkI=None
-NeEkG=classmethod
-NeEkF=str
 from localstack.services.cloudformation.service_models import REF_ID_ATTRS,GenericBaseModel
 from localstack.utils.aws import aws_stack
 from localstack.utils.common import clone,select_attributes
 from localstack_ext.services.cloudformation.service_models import LOG
 class EC2VPCEndpoint(GenericBaseModel):
- @NeEkn
+ @staticmethod
  def cloudformation_type():
   return "AWS::EC2::VPCEndpoint"
  def fetch_state(self,stack_name,resources):
   client=aws_stack.connect_to_service("ec2")
   result=client.describe_vpc_endpoints(Filters=[{"Name":"service-name","Values":[self.props["ServiceName"]]},{"Name":"vpc-id","Values":[self.props["VpcId"]]}])
   result=result["VpcEndpoints"]
-  return(result or[NeEkI])[0]
+  return(result or[None])[0]
  def get_physical_resource_id(self,attribute,**kwargs):
   return self.props.get("VpcEndpointId")
- @NeEkn
+ @staticmethod
  def get_deploy_templates():
   return{"create":{"function":"create_vpc_endpoint","parameters":{"ServiceName":"ServiceName","PolicyDocument":param_json_to_str("PolicyDocument"),"VpcId":"VpcId","SecurityGroupIds":"SecurityGroupIds","SubnetIds":"SubnetIds","RouteTableIds":"RouteTableIds","VpcEndpointType":"VpcEndpointType","PrivateDnsEnabled":"PrivateDnsEnabled"}}}
 class EC2ElasticIP(GenericBaseModel):
- @NeEkn
+ @staticmethod
  def cloudformation_type():
   return "AWS::EC2::EIP"
- def get_physical_resource_id(self,attribute=NeEkI,**kwargs):
+ def get_physical_resource_id(self,attribute=None,**kwargs):
   return self.props.get("PublicIp")
  def fetch_state(self,stack_name,resources):
   if self.get_physical_resource_id():
    return self.state
- @NeEkG
+ @classmethod
  def get_deploy_templates(cls):
   def allocate_address(resource_id,resources,resource_type,func,stack_name,*args,**kwargs):
    resource=cls(resources[resource_id])
@@ -42,7 +39,7 @@ class EC2ElasticIP(GenericBaseModel):
    return result
   return{"create":{"function":allocate_address},"delete":{"function":"release_address","parameters":["PublicIp","AllocationId"]}}
 class SubnetRouteTableAssociation(GenericBaseModel):
- @NeEkn
+ @staticmethod
  def cloudformation_type():
   return "AWS::EC2::SubnetRouteTableAssociation"
  def get_physical_resource_id(self,attribute,**kwargs):
@@ -55,8 +52,10 @@ class SubnetRouteTableAssociation(GenericBaseModel):
   tables=client.describe_route_tables(RouteTableIds=[table_id])["RouteTables"]
   tables=[t for t in tables if t["RouteTableId"]==table_id]
   if tables:
-   assocs=[a for a in tables[0].get("Associations",[])if a["SubnetId"]==subnet_id]
-   return(assocs or[NeEkI])[0]
+   associations=tables[0].get("Associations",[])
+   matching=[a for a in associations if a.get("SubnetId")==subnet_id]
+   return(matching or[None])[0]
+ @staticmethod
  def get_deploy_templates():
   return{"create":{"function":"associate_route_table","parameters":{"RouteTableId":"RouteTableId","SubnetId":"SubnetId"}},"delete":{"function":"disassociate_route_table","parameters":{"AssociationId":"PhysicalResourceId"}}}
 class SecurityGroupInOrEgress(GenericBaseModel):
@@ -73,42 +72,51 @@ class SecurityGroupInOrEgress(GenericBaseModel):
   src_grp_name=rp.get("SourceSecurityGroupName")
   src_grp_id=rp.get("SourceSecurityGroupId")
   dst_grp_id=rp.get("DestinationSecurityGroupId")
-  if result:
-   perms=result[0].get("IpPermissions" if self.is_ingress()else "IpPermissionsEgress")
-   result=[]
-   for perm in perms:
-    if NeEkF(perm["IpProtocol"])!=NeEkF(rp["IpProtocol"]):
-     continue
-    if perm.get("FromPort")!=rp.get("FromPort")or perm.get("ToPort")!=rp.get("ToPort"):
-     continue
-    if not self.is_ingress():
-     return perm
-    groups=perm.get("UserIdGroupPairs",[])
-    groups=[g for g in groups if g.get("GroupId")in[src_grp_id,dst_grp_id]or g.get("GroupName")==src_grp_name]
-    if groups:
-     return perm
- @NeEkG
+  if not result:
+   return
+  perms=result[0].get("IpPermissions" if self.is_ingress()else "IpPermissionsEgress")
+  for perm in perms:
+   if str(perm["IpProtocol"])!=str(rp["IpProtocol"]):
+    continue
+   if perm.get("FromPort")!=rp.get("FromPort")or perm.get("ToPort")!=rp.get("ToPort"):
+    continue
+   if not self.is_ingress():
+    return perm
+   groups=perm.get("UserIdGroupPairs",[])
+   groups=[g for g in groups if g.get("GroupId")in[src_grp_id,dst_grp_id]or g.get("GroupName")==src_grp_name]
+   if groups:
+    return perm
+ @classmethod
  def is_ingress(cls):
   return "Ingress" in cls.cloudformation_type()
- @NeEkG
+ @classmethod
+ def get_vpc_and_name_for_security_group(cls,group_id:str)->Tuple[str,str]:
+  client=aws_stack.connect_to_service("ec2")
+  groups=client.describe_security_groups(GroupIds=[group_id])["SecurityGroups"]
+  vpc_id=groups and groups[0].get("VpcId")or None
+  group_name=groups and groups[0]["GroupName"]or None
+  return vpc_id,group_name
+ @classmethod
  def get_deploy_templates(cls):
   def create_params(params,**kwargs):
    result=clone(params)
    source_group_name=result.get("SourceSecurityGroupName")
-   source_group_id=result.pop("SourceSecurityGroupId",NeEkI)
-   vpc_id=NeEkI
+   source_group_id=result.pop("SourceSecurityGroupId",None)
+   vpc_id=None
    if cls.is_ingress()and source_group_id and not source_group_name:
-    client=aws_stack.connect_to_service("ec2")
-    groups=client.describe_security_groups(GroupIds=[source_group_id])["SecurityGroups"]
-    result["SourceSecurityGroupName"]=groups and groups[0]["GroupName"]or NeEkI
-    vpc_id=groups and groups[0].get("VpcId")or NeEkI
-   dst_group_id=result.pop("DestinationSecurityGroupId",NeEkI)
+    vpc_id,group_name=cls.get_vpc_and_name_for_security_group(source_group_id)
+    result["SourceSecurityGroupName"]=group_name
+   dst_group_id=result.pop("DestinationSecurityGroupId",None)
+   if cls.is_ingress()and not dst_group_id:
+    dst_group_id=result.get("GroupId")
+    if dst_group_id and not vpc_id:
+     vpc_id,_=cls.get_vpc_and_name_for_security_group(dst_group_id)
    if not cls.is_ingress()and not dst_group_id:
     LOG.info("TODO: Add support for DestinationPrefixListId for %s"%cls.cloudformation_type())
    if result.get("IpProtocol"):
-    result["IpProtocol"]=NeEkF(result.get("IpProtocol"))
-   description=result.pop("Description",NeEkI)
-   cidr_ipv6=result.pop("CidrIpv6",NeEkI)
+    result["IpProtocol"]=str(result.get("IpProtocol"))
+   description=result.pop("Description",None)
+   cidr_ipv6=result.pop("CidrIpv6",None)
    if cidr_ipv6 or vpc_id:
     cidr_ip=result.get("CidrIp")
     cidr_ip=cidr_ip or("127.0.0.1/32" if description else cidr_ip)
@@ -129,11 +137,11 @@ class SecurityGroupInOrEgress(GenericBaseModel):
   func_name=("authorize_security_group_ingress" if cls.is_ingress()else "authorize_security_group_egress")
   return{"create":{"function":func_name,"parameters":create_params}}
 class SecurityGroupEgress(SecurityGroupInOrEgress):
- @NeEkn
+ @staticmethod
  def cloudformation_type():
   return "AWS::EC2::SecurityGroupEgress"
 class SecurityGroupIngress(SecurityGroupInOrEgress):
- @NeEkn
+ @staticmethod
  def cloudformation_type():
   return "AWS::EC2::SecurityGroupIngress"
 # Created by pyminifier (https://github.com/liftoff/pyminifier)
