@@ -1,13 +1,9 @@
 from localstack.services.cloudformation.deployment_utils import lambda_keys_to_lower
-DbBvY=staticmethod
-DbBvw=None
-DbBvn=super
-DbBvx=str
 from localstack.services.cloudformation.service_models import GenericBaseModel
 from localstack.utils.aws import aws_stack
 from localstack_ext.services.cloudformation.service_models import(lambda_add_tags,lambda_convert_types)
 class ECSCluster(GenericBaseModel):
- @DbBvY
+ @staticmethod
  def cloudformation_type():
   return "AWS::ECS::Cluster"
  def get_physical_resource_id(self,attribute,**kwargs):
@@ -19,12 +15,12 @@ class ECSCluster(GenericBaseModel):
   cluster=self.resolve_refs_recursively(stack_name,props.get("ClusterName"),resources)
   ecs_client=aws_stack.connect_to_service("ecs")
   result=ecs_client.describe_clusters(clusters=[cluster])["clusters"]
-  return(result or[DbBvw])[0]
- @DbBvY
+  return(result or[None])[0]
+ @staticmethod
  def get_deploy_templates():
   return{"create":{"function":"create_cluster","parameters":lambda_keys_to_lower()}}
 class ECSService(GenericBaseModel):
- @DbBvY
+ @staticmethod
  def cloudformation_type():
   return "AWS::ECS::Service"
  def get_physical_resource_id(self,attribute,**kwargs):
@@ -35,16 +31,16 @@ class ECSService(GenericBaseModel):
   service_name=self.resolve_refs_recursively(stack_name,props.get("ServiceName"),resources)
   ecs_client=aws_stack.connect_to_service("ecs")
   result=ecs_client.describe_services(cluster=cluster,services=[service_name])["services"]
-  return(result or[DbBvw])[0]
+  return(result or[None])[0]
  def get_cfn_attribute(self,attribute_name):
   if attribute_name=="Name":
    return self.props.get("ServiceName")
-  return DbBvn(ECSService,self).get_cfn_attribute(attribute_name)
- @DbBvY
+  return super(ECSService,self).get_cfn_attribute(attribute_name)
+ @staticmethod
  def get_deploy_templates():
   return{"create":{"function":"create_service","parameters":lambda_add_tags(lambda_keys_to_lower())}}
 class ECSTaskDefinition(GenericBaseModel):
- @DbBvY
+ @staticmethod
  def cloudformation_type():
   return "AWS::ECS::TaskDefinition"
  def get_physical_resource_id(self,attribute,**kwargs):
@@ -54,8 +50,8 @@ class ECSTaskDefinition(GenericBaseModel):
   task_def=self.resolve_refs_recursively(stack_name,task_def,resources)
   ecs_client=aws_stack.connect_to_service("ecs")
   task_defs=ecs_client.list_task_definitions(familyPrefix=task_def)["taskDefinitionArns"]
-  return task_defs and{"taskDefinitionArn":task_defs[0]}or DbBvw
- @DbBvY
+  return task_defs and{"taskDefinitionArn":task_defs[0]}or None
+ @staticmethod
  def get_deploy_templates():
-  return{"create":{"function":"register_task_definition","parameters":lambda_convert_types(lambda_keys_to_lower(),{".memory":DbBvx,".cpu":DbBvx})}}
+  return{"create":{"function":"register_task_definition","parameters":lambda_convert_types(lambda_keys_to_lower(),{".memory":str,".cpu":str})}}
 # Created by pyminifier (https://github.com/liftoff/pyminifier)
