@@ -1,22 +1,19 @@
 from localstack.services.cloudformation.service_models import GenericBaseModel
-hGpmB=staticmethod
-hGpme=None
-hGpmb=classmethod
 from localstack.utils.aws import aws_stack
 from localstack.utils.common import clone
 class KafkaCluster(GenericBaseModel):
- @hGpmB
+ @staticmethod
  def cloudformation_type():
   return "AWS::MSK::Cluster"
- def get_physical_resource_id(self,attribute=hGpme,**kwargs):
+ def get_physical_resource_id(self,attribute=None,**kwargs):
   return self.props.get("ClusterArn")
  def fetch_state(self,stack_name,resources):
   client=aws_stack.connect_to_service("kafka")
   cluster_name=self.resolve_refs_recursively(stack_name,self.props["ClusterName"],resources)
   clusters=client.list_clusters()["ClusterInfoList"]
   clusters=[c for c in clusters if c["ClusterName"]==cluster_name]
-  return(clusters or[hGpme])[0]
- @hGpmb
+  return(clusters or[None])[0]
+ @classmethod
  def get_deploy_templates(cls):
   def _create_params(params,resource_id,resources,**kwargs):
    resource=cls(resources[resource_id])
