@@ -1,57 +1,65 @@
+from typing import Dict
 from localstack.services.cloudformation.service_models import GenericBaseModel
-xvdhE=staticmethod
-xvdhA=None
-xvdhV=super
-xvdhs=classmethod
-xvdht=int
 from localstack.utils.aws import aws_stack
+from localstack.utils.common import short_uid
 class RDSDBSubnetGroup(GenericBaseModel):
- @xvdhE
+ @staticmethod
  def cloudformation_type():
   return "AWS::RDS::DBSubnetGroup"
- def get_physical_resource_id(self,attribute=xvdhA,**kwargs):
+ def get_physical_resource_id(self,attribute=None,**kwargs):
   return self.props.get("DBSubnetGroupName")
  def fetch_state(self,stack_name,resources):
   client=aws_stack.connect_to_service("rds")
   group_name=self.resolve_refs_recursively(stack_name,self.props.get("DBSubnetGroupName"),resources)
   group=client.describe_db_subnet_groups()["DBSubnetGroups"]
   match=[i for i in group if i["DBSubnetGroupName"]==group_name]
-  return(match or[xvdhA])[0]
- @xvdhE
+  return(match or[None])[0]
+ @staticmethod
  def get_deploy_templates():
   return{"create":{"function":"create_db_subnet_group"},"delete":{"function":"delete_db_subnet_group","parameters":{"DBSubnetGroupName":"DBSubnetGroupName"}}}
 class RDSDBCluster(GenericBaseModel):
- @xvdhE
+ @staticmethod
  def cloudformation_type():
   return "AWS::RDS::DBCluster"
- def get_physical_resource_id(self,attribute=xvdhA,**kwargs):
+ @staticmethod
+ def add_defaults(resource:Dict,stack_name:str):
+  props=resource["Properties"]
+  if not props.get("DBClusterIdentifier"):
+   props["DBClusterIdentifier"]=f"dbc-{short_uid()}"
+ def get_physical_resource_id(self,attribute=None,**kwargs):
   return self.props.get("DBClusterIdentifier")
  def fetch_state(self,stack_name,resources):
   client=aws_stack.connect_to_service("rds")
   clusters=client.describe_db_clusters().get("DBClusters",[])
   cluster_id=self.resolve_refs_recursively(stack_name,self.props.get("DBClusterIdentifier"),resources)
   match=[c for c in clusters if c["DBClusterIdentifier"]==cluster_id]
-  return(match or[xvdhA])[0]
+  return(match or[None])[0]
  def get_cfn_attribute(self,attribute):
   if attribute=="Endpoint.Address":
    return "localhost"
   props=self.props
   if attribute=="Endpoint.Port":
    return props.get("Port")or props.get("Endpoint",{}).get("Port")
-  return xvdhV(RDSDBCluster,self).get_cfn_attribute(attribute)
- @xvdhE
+  return super(RDSDBCluster,self).get_cfn_attribute(attribute)
+ @staticmethod
  def get_deploy_templates():
   attrs=["AvailabilityZones","BackupRetentionPeriod","CharacterSetName","DatabaseName","DBClusterIdentifier","DBClusterParameterGroupName","VpcSecurityGroupIds","DBSubnetGroupName","Engine","EngineVersion","Port","MasterUsername","MasterUserPassword","OptionGroupName","PreferredBackupWindow","PreferredMaintenanceWindow","ReplicationSourceIdentifier","Tags","StorageEncrypted","KmsKeyId","PreSignedUrl","EnableIAMDatabaseAuthentication","BacktrackWindow","EnableCloudwatchLogsExports","EngineMode","ScalingConfiguration","DeletionProtection","GlobalClusterIdentifier","EnableHttpEndpoint","CopyTagsToSnapshot","Domain","DomainIAMRoleName","EnableGlobalWriteForwarding","SourceRegion"]
   def _params(params,**kwargs):
    params={k:v for k,v in params.items()if k in attrs}
+   scaling_config=params.get("ScalingConfiguration")
+   if scaling_config:
+    if "MinCapacity" in scaling_config:
+     scaling_config["MinCapacity"]=int(scaling_config["MinCapacity"])
+    if "MaxCapacity" in scaling_config:
+     scaling_config["MaxCapacity"]=int(scaling_config["MaxCapacity"])
    return params
-  result={"create":{"function":"create_db_cluster","parameters":_params}}
+  result={"create":{"function":"create_db_cluster","parameters":_params,"types":{"BackupRetentionPeriod":int,"Port":int}},"delete":{"function":"delete_db_cluster","parameters":["DBClusterIdentifier"]}}
   return result
 class RDSDBParameterGroup(GenericBaseModel):
- @xvdhE
+ @staticmethod
  def cloudformation_type():
   return "AWS::RDS::DBParameterGroup"
- def get_physical_resource_id(self,attribute=xvdhA,**kwargs):
+ def get_physical_resource_id(self,attribute=None,**kwargs):
   return self.props.get("DBParameterGroupName")
  def fetch_state(self,stack_name,resources):
   client=aws_stack.connect_to_service("rds")
@@ -60,15 +68,20 @@ class RDSDBParameterGroup(GenericBaseModel):
   family=self.resolve_refs_recursively(stack_name,props.get("Family"),resources)
   groups=client.describe_db_parameter_groups()["DBParameterGroups"]
   match=[g for g in groups if g["Family"]==family and g["Description"]==descr]
-  return(match or[xvdhA])[0]
- @xvdhE
+  return(match or[None])[0]
+ @staticmethod
  def get_deploy_templates():
   return{"create":{"function":"create_db_parameter_group","parameters":{"DBParameterGroupName":"DBParameterGroupName","DBParameterGroupFamily":"Family","Description":"Description","Tags":"Tags"}},"delete":{"function":"delete_db_parameter_group","parameters":["DBParameterGroupName"]}}
 class RDSDBInstance(GenericBaseModel):
- @xvdhE
+ @staticmethod
  def cloudformation_type():
   return "AWS::RDS::DBInstance"
- def get_physical_resource_id(self,attribute,**kwargs):
+ @staticmethod
+ def add_defaults(resource:Dict,stack_name:str):
+  props=resource["Properties"]
+  if not props.get("DBInstanceIdentifier"):
+   props["DBInstanceIdentifier"]=f"db-{short_uid()}"
+ def get_physical_resource_id(self,attribute=None,**kwargs):
   return self.props.get("DBInstanceIdentifier")
  def get_cfn_attribute(self,attribute):
   if attribute=="Endpoint.Address":
@@ -76,15 +89,16 @@ class RDSDBInstance(GenericBaseModel):
   props=self.props
   if attribute=="Endpoint.Port":
    return props.get("Endpoint",{}).get("Port")or props.get("Port")
-  return xvdhV(RDSDBInstance,self).get_cfn_attribute(attribute)
- @xvdhs
- def fetch_details(cls,db_name):
+  return super(RDSDBInstance,self).get_cfn_attribute(attribute)
+ def fetch_state(self,stack_name,resources):
+  db_id=self.props.get("DBInstanceIdentifier")
+  db_id=self.resolve_refs_recursively(stack_name,db_id,resources)
   client=aws_stack.connect_to_service("rds")
   instances=client.describe_db_instances()["DBInstances"]
-  match=[i for i in instances if i["DBName"]==db_name]
-  return(match or[xvdhA])[0]
- @xvdhE
+  match=[i for i in instances if i["DBInstanceIdentifier"]==db_id]
+  return(match or[None])[0]
+ @staticmethod
  def get_deploy_templates():
   attrs=["DBName","DBInstanceIdentifier","AllocatedStorage","DBInstanceClass","Engine","MasterUsername","MasterUserPassword","DBSecurityGroups","AvailabilityZone","DBSubnetGroupName","PreferredMaintenanceWindow","DBParameterGroupName","BackupRetentionPeriod","PreferredBackupWindow","Port","MultiAZ","EngineVersion","AutoMinorVersionUpgrade","LicenseModel","Iops","OptionGroupName","CharacterSetName","NcharCharacterSetName","PubliclyAccessible","Tags","DBClusterIdentifier","StorageType","TdeCredentialArn","TdeCredentialPassword","StorageEncrypted","KmsKeyId","Domain","CopyTagsToSnapshot","MonitoringInterval","MonitoringRoleArn","DomainIAMRoleName","PromotionTier","Timezone","EnableIAMDatabaseAuthentication","EnablePerformanceInsights","PerformanceInsightsKMSKeyId","PerformanceInsightsRetentionPeriod","EnableCloudwatchLogsExports","ProcessorFeatures","DeletionProtection","MaxAllocatedStorage","EnableCustomerOwnedIp"]
-  return{"create":{"function":"create_db_instance","parameters":attrs+[{"VpcSecurityGroupIds":"VPCSecurityGroups"}],"types":{"AllocatedStorage":xvdht}},"delete":{"function":"delete_db_instance","parameters":["DBInstanceIdentifier"]}}
+  return{"create":{"function":"create_db_instance","parameters":attrs+[{"VpcSecurityGroupIds":"VPCSecurityGroups"}],"types":{"AllocatedStorage":int,"Port":int}},"delete":{"function":"delete_db_instance","parameters":["DBInstanceIdentifier"]}}
 # Created by pyminifier (https://github.com/liftoff/pyminifier)
