@@ -1,14 +1,8 @@
 from localstack.services.cloudformation.deployment_utils import generate_default_name_without_stack
-hxYQt=staticmethod
-hxYQq=None
-hxYQP=all
-hxYQT=super
-hxYQi=str
-hxYQA=classmethod
 from localstack.services.cloudformation.service_models import GenericBaseModel
 from localstack.utils.aws import aws_stack
 class SESTemplate(GenericBaseModel):
- @hxYQt
+ @staticmethod
  def cloudformation_type():
   return "AWS::SES::Template"
  def fetch_state(self,stack_name,resources):
@@ -17,30 +11,30 @@ class SESTemplate(GenericBaseModel):
   tmpl_name=self.resolve_refs_recursively(stack_name,template_name,resources)
   templates=client.list_templates().get("TemplatesMetadata",[])
   template=[t for t in templates if t["Name"]==tmpl_name]
-  return(template or[hxYQq])[0]
- def get_physical_resource_id(self,attribute=hxYQq,**kwargs):
+  return(template or[None])[0]
+ def get_physical_resource_id(self,attribute=None,**kwargs):
   return self.props.get("Template",{}).get("TemplateName")
  def update_resource(self,new_resource,stack_name,resources):
   client=aws_stack.connect_to_service("ses")
   new_props=new_resource["Properties"]
   new_template=new_props.get("Template",{})
   template=client.get_template(TemplateName=new_template["TemplateName"])["Template"]
-  if hxYQP(template.get(attr,"")==new_template.get(attr,"")for attr in["SubjectPart","TextPart","HtmlPart"]):
+  if all(template.get(attr,"")==new_template.get(attr,"")for attr in["SubjectPart","TextPart","HtmlPart"]):
    return
   return client.update_template(**new_props)
- @hxYQt
+ @staticmethod
  def get_deploy_templates():
   return{"create":{"function":"create_template"},"delete":{"function":"delete_template","parameters":{"TemplateName":"TemplateName"}}}
 class SESReceiptRuleSet(GenericBaseModel):
- @hxYQt
+ @staticmethod
  def cloudformation_type():
   return "AWS::SES::ReceiptRuleSet"
- def get_physical_resource_id(self,attribute=hxYQq,**kwargs):
+ def get_physical_resource_id(self,attribute=None,**kwargs):
   return self.props.get("RuleSetName")
  def get_cfn_attribute(self,attribute):
-  return hxYQT(SESReceiptRuleSet,self).get_cfn_attribute(attribute)
- @hxYQt
- def add_defaults(resource,stack_name:hxYQi):
+  return super(SESReceiptRuleSet,self).get_cfn_attribute(attribute)
+ @staticmethod
+ def add_defaults(resource,stack_name:str):
   role=resource["Properties"]
   if not role.get("RuleSetName"):
    role["RuleSetName"]=generate_default_name_without_stack(resource["LogicalResourceId"])
@@ -49,34 +43,34 @@ class SESReceiptRuleSet(GenericBaseModel):
   rule_set_name=self.props.get("RuleSetName")
   rule_set_name=self.resolve_refs_recursively(stack_name,rule_set_name,resources)
   rule_set=client.describe_receipt_rule_set(RuleSetName=rule_set_name)
-  return rule_set or hxYQq
- @hxYQA
+  return rule_set or None
+ @classmethod
  def fetch_details(cls,rule_set_name):
   client=aws_stack.connect_to_service("ses")
   rule=client.describe_receipt_rule_set(RuleSetName=rule_set_name)
-  return rule or hxYQq
- @hxYQt
+  return rule or None
+ @staticmethod
  def get_deploy_templates():
   return{"create":{"function":"create_receipt_rule_set"},"delete":{"function":"delete_receipt_rule_set"}}
 class SESReceiptRule(GenericBaseModel):
- @hxYQt
+ @staticmethod
  def cloudformation_type():
   return "AWS::SES::ReceiptRule"
- def get_physical_resource_id(self,attribute=hxYQq,**kwargs):
+ def get_physical_resource_id(self,attribute=None,**kwargs):
   return self.props.get("Rule",{}).get("Name")
  def get_cfn_attribute(self,attribute):
-  return hxYQT(SESReceiptRule,self).get_cfn_attribute(attribute)
- @hxYQA
+  return super(SESReceiptRule,self).get_cfn_attribute(attribute)
+ @classmethod
  def fetch_details(cls,rule_set_name,rule_name):
   client=aws_stack.connect_to_service("ses")
   rule=client.describe_receipt_rule(RuleSetName=rule_set_name,RuleName=rule_name).get("Rule")
-  return rule or hxYQq
- @hxYQt
- def add_defaults(resource,stack_name:hxYQi):
+  return rule or None
+ @staticmethod
+ def add_defaults(resource,stack_name:str):
   rule=resource["Properties"]["Rule"]
   if not rule.get("Name"):
    rule["Name"]=generate_default_name_without_stack(resource["LogicalResourceId"])
- @hxYQt
+ @staticmethod
  def get_deploy_templates():
   return{"create":{"function":"create_receipt_rule"},"delete":{"function":"delete_receipt_rule","parameters":{"RuleSetName":"RuleSetName","RuleName":lambda params,**kwargs:params["Rule"]["Name"]}}}
 # Created by pyminifier (https://github.com/liftoff/pyminifier)
